==> haskell-tasty-rerun-1.1.19-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-rerun
version:              1.1.19
visibility:           public
id:                   tasty-rerun-1.1.19-CpK9ylpZUhxC3O1SEntihF
key:                  tasty-rerun-1.1.19-CpK9ylpZUhxC3O1SEntihF
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  34c8e0fd4335bd06d1ecf9c3db42979b
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-rerun
hs-libraries:         HStasty-rerun-1.1.19-CpK9ylpZUhxC3O1SEntihF
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    optparse-applicative-0.18.1.0-B5S7p3yvcpkHKfw0kuCuBU
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C tasty-1.5-Cig7BoCvuBI5IwHg7ZMnX
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-rerun-1.1.19-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-rerun
version:              1.1.19
visibility:           public
id:                   tasty-rerun-1.1.19-FC66JbQ3Cr1JrY5B7SjsaQ
key:                  tasty-rerun-1.1.19-FC66JbQ3Cr1JrY5B7SjsaQ
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  58b8b7eb581014f063cdaac6558c300c
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-rerun
hs-libraries:         HStasty-rerun-1.1.19-FC66JbQ3Cr1JrY5B7SjsaQ
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    optparse-applicative-0.18.1.0-6krVryETStC73hI3cDgd1Y
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-2VF3Rdd37bz4PqVnWDagdL transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
